@@ -99,7 +99,7 @@ class MuminDataset:
               Network Posts_ (2021)
     '''
     download_url: str = ('https://github.com/CLARITI-REPHRAIN/mumin-build/raw/'
-                         '7cdf5c5ea3689af597eeb1f0d39c3412ea30c3b7'
+                         '22cbc45ad014464a0ee37338a61de1e5e64e756a'
                          '/data/mumin.zip')
     _node_dump: List[str] = ['claim', 'tweet', 'user', 'image', 'article',
                              'hashtag', 'reply']
@@ -208,7 +208,8 @@ class MuminDataset:
             self._rehydrate(node_type='reply')
 
             # Update the IDs of the data that was there pre-hydration
-            self._update_precomputed_ids()
+            self.nodes, self.rels = self._updator.update_all(nodes=self.nodes,
+                                                             rels=self.rels)
 
             # Extract data from the rehydrated tweets
             self.nodes, self.rels = self._extractor.extract_all(
@@ -408,6 +409,7 @@ class MuminDataset:
         if not self.include_timelines:
             src_tweet_ids = (self.rels[('tweet', 'discusses', 'claim')]
                                  .src
+                                 .astype(int)
                                  .tolist())
             is_src = self.nodes['tweet'].tweet_id.isin(src_tweet_ids)
             self.nodes['tweet'] = self.nodes['tweet'].loc[is_src]
@@ -420,6 +422,7 @@ class MuminDataset:
         Args:
             node_type (str): The type of node to rehydrate.
         '''
+
         if (node_type in self.nodes.keys() and
                 (node_type != 'reply' or self.include_replies)):
 
@@ -429,8 +432,9 @@ class MuminDataset:
             # these into source tweets and the rest (i.e., timeline tweets)
             if node_type == 'tweet':
                 source_tweet_ids = (self.rels[('tweet', 'discusses', 'claim')]
-                                    .src
-                                    .tolist())
+                                        .astype(int)
+                                        .src
+                                        .tolist())
                 tweet_ids = [tweet_id
                              for tweet_id in self.nodes[node_type]
                                                  .tweet_id
@@ -448,6 +452,12 @@ class MuminDataset:
                 params = dict(tweet_ids=source_tweet_ids)
                 source_tweet_dfs = self._twitter.rehydrate_tweets(**params)
 
+                # Return error if there are no tweets were rehydrated. This is
+                # probably because the bearer token is wrong
+                if len(source_tweet_dfs) == 0:
+                    raise RuntimeError('No tweets were rehydrated. Check if '
+                                       'the bearer token is correct.')
+
                 if len(tweet_ids) == 0:
                     tweet_dfs = {key: pd.DataFrame()
                                  for key in source_tweet_dfs.keys()}
@@ -457,6 +467,12 @@ class MuminDataset:
                 params = dict(tweet_ids=tweet_ids)
                 tweet_dfs = self._twitter.rehydrate_tweets(**params)
 
+                # Return error if there are no tweets were rehydrated. This is
+                # probably because the bearer token is wrong
+                if len(tweet_dfs) == 0:
+                    raise RuntimeError('No tweets were rehydrated. Check if '
+                                       'the bearer token is correct.')
+
                 if len(source_tweet_ids) == 0:
                     source_tweet_dfs = {key: pd.DataFrame()
                                         for key in tweet_dfs.keys()}
@@ -479,10 +495,11 @@ class MuminDataset:
             self.nodes['user'] = user_df
 
             # Add prehydration tweet features back to the tweets
-            self.nodes[node_type] = pd.merge(left=self.nodes[node_type],
-                                             right=prehydration_df,
-                                             how='left',
-                                             on='tweet_id')
+            self.nodes[node_type] = (self.nodes[node_type]
+                                         .merge(prehydration_df,
+                                                on='tweet_id',
+                                                how='outer')
+                                         .reset_index(drop=True))
 
             # Extract and store images
             # Note: This will store `self.nodes['image']`, but this is only
@@ -505,19 +522,6 @@ class MuminDataset:
 
                 self.nodes['image'] = image_df
 
-            return self
-
-    def _update_precomputed_ids(self):
-        '''Update the node IDs in the pre-hydrated dataset.
-
-        In the dataset nodes are uniquely characterised using their Twitter
-        IDs, like node IDs and user IDs, and articles and claims have IDs from
-        Neo4j. After rehydration we use a simple enumeration as the IDs of the
-        node types, and this updates the nodes and relations to those IDs.
-        '''
-        logger.info('Updating precomputed IDs')
-        self.nodes, self.rels = self._updator.update_all(nodes=self.nodes,
-                                                         rels=self.rels)
         return self
 
     def add_embeddings(self,
@@ -719,6 +723,23 @@ class MuminDataset:
                                      title='str',
                                      content='str')
 
+        # Create conversion function for missing values
+        def fill_na_values(dtype: Union[str, dict]):
+            if dtype == 'uint64':
+                return 0
+            elif dtype == 'bool':
+                return False
+            elif dtype == dict(created_at='datetime64[ns]'):
+                return np.datetime64('NaT')
+            elif dtype == 'category':
+                return 'NaN'
+            elif dtype == 'str':
+                return ''
+            elif dtype == 'numpy':
+                return np.zeros((1, 1))
+            else:
+                return np.nan
+
         # Loop over all nodes
         for ntype, dtype_dict in dtypes.items():
             if ntype in self.nodes.keys():
@@ -729,6 +750,13 @@ class MuminDataset:
                                        if dtype != 'numpy'}
                 for col, dtype in dtype_dict_no_numpy.items():
                     if col in self.nodes[ntype].columns:
+
+                        # Fill NaN values with canonical values in accordance
+                        # with the datatype
+                        self.nodes[ntype][col].fillna(fill_na_values(dtype),
+                                                      inplace=True)
+
+                        # Set the dtype
                         self.nodes[ntype][col] = (self.nodes[ntype][col]
                                                   .astype(dtype))
 
@@ -738,6 +766,13 @@ class MuminDataset:
 
                 for col, dtype in dtype_dict.items():
                     if dtype == 'numpy' and col in self.nodes[ntype].columns:
+
+                        # Fill NaN values with canonical values in accordance
+                        # with the datatype
+                        self.nodes[ntype][col].fillna(fill_na_values(dtype),
+                                                      inplace=True)
+
+                        # Set the dtype
                         self.nodes[ntype][col] = (self.nodes[ntype][col]
                                                       .map(numpy_fn))
 
@@ -759,6 +794,7 @@ class MuminDataset:
 
     def _remove_islands(self):
         '''Removes nodes and relations that are not connected to anything'''
+
         # Loop over all the node types
         for node_type, node_df in self.nodes.items():
 
